@@ -13,7 +13,6 @@
 
 import json
 import logging
-import os
 import requests
 
 from toscaparser.utils.gettextutils import _
@@ -26,9 +25,6 @@ log = logging.getLogger('heat-translator')
 # Name used to dynamically load appropriate map class.
 TARGET_CLASS_NAME = 'ToscaCompute'
 
-# Required environment variables to create novaclient object.
-ENV_VARIABLES = ['OS_AUTH_URL', 'OS_PASSWORD', 'OS_USERNAME', 'OS_TENANT_NAME']
-
 # A design issue to be resolved is how to translate the generic TOSCA server
 # properties to OpenStack flavors and images.  At the Atlanta design summit,
 # there was discussion on using Glance to store metadata and Graffiti to
@@ -116,49 +112,30 @@ class ToscaCompute(HotResource):
         if host_capability:
             for prop in host_capability.get_properties_objects():
                 host_cap_props[prop.name] = prop.value
-            flavor = self._best_flavor(host_cap_props)
+            # if HOST properties are not specified, we should not attempt to
+            # find best match of flavor
+            if host_cap_props:
+                flavor = self._best_flavor(host_cap_props)
         if os_capability:
             for prop in os_capability.get_properties_objects():
                 os_cap_props[prop.name] = prop.value
-            image = self._best_image(os_cap_props)
+            # if OS properties are not specified, we should not attempt to
+            # find best match of image
+            if os_cap_props:
+                image = self._best_image(os_cap_props)
         hot_properties['flavor'] = flavor
         hot_properties['image'] = image
         return hot_properties
 
-    def _check_for_env_variables(self):
-        return set(ENV_VARIABLES) < set(os.environ.keys())
-
     def _create_nova_flavor_dict(self):
         '''Populates and returns the flavors dict using Nova ReST API'''
-
-        tenant_name = os.getenv('OS_TENANT_NAME')
-        username = os.getenv('OS_USERNAME')
-        password = os.getenv('OS_PASSWORD')
-        auth_url = os.getenv('OS_AUTH_URL')
-
-        auth_dict = {
-            "auth": {
-                "tenantName": tenant_name,
-                "passwordCredentials": {
-                    "username": username,
-                    "password": password
-                }
-            }
-        }
-        headers = {'Content-Type': 'application/json'}
         try:
-            keystone_response = requests.post(auth_url + '/tokens',
-                                              data=json.dumps(auth_dict),
-                                              headers=headers)
-            if keystone_response.status_code != 200:
+            access_dict = translator.common.utils.get_ks_access_dict()
+            access_token = translator.common.utils.get_token_id(access_dict)
+            if access_token is None:
                 return None
-            access_dict = json.loads(keystone_response.content)
-            access_token = access_dict['access']['token']['id']
-            service_catalog = access_dict['access']['serviceCatalog']
-            nova_url = ''
-            for service in service_catalog:
-                if service['type'] == 'compute':
-                    nova_url = service['endpoints'][0]['publicURL']
+            nova_url = translator.common.utils.get_url_for(access_dict,
+                                                           'compute')
             if not nova_url:
                 return None
             nova_response = requests.get(nova_url + '/flavors/detail',
@@ -182,11 +159,53 @@ class ToscaCompute(HotResource):
             return None
         return flavor_dict
 
+    def _populate_image_dict(self):
+        '''Populates and returns the images dict using Glance ReST API'''
+        images_dict = {}
+        try:
+            access_dict = translator.common.utils.get_ks_access_dict()
+            access_token = translator.common.utils.get_token_id(access_dict)
+            if access_token is None:
+                return None
+            glance_url = translator.common.utils.get_url_for(access_dict,
+                                                             'image')
+            if not glance_url:
+                return None
+            glance_response = requests.get(glance_url + '/v2/images',
+                                           headers={'X-Auth-Token':
+                                                    access_token})
+            if glance_response.status_code != 200:
+                return None
+            images = json.loads(glance_response.content)["images"]
+            for image in images:
+                image_resp = requests.get(glance_url + '/v2/images/' +
+                                          image["id"],
+                                          headers={'X-Auth-Token':
+                                                   access_token})
+                if image_resp.status_code != 200:
+                    continue
+                metadata = ["architecture", "type", "distribution", "version"]
+                image_data = json.loads(image_resp.content)
+                if any(key in image_data.keys() for key in metadata):
+                    images_dict[image_data["name"]] = dict()
+                    for key in metadata:
+                        if key in image_data.keys():
+                            images_dict[image_data["name"]][key] = \
+                                image_data[key]
+                else:
+                    continue
+
+        except Exception as e:
+            # Handles any exception coming from openstack
+            log.warn(_('Choosing predefined flavors since received '
+                       'Openstack Exception: %s') % str(e))
+        return images_dict
+
     def _best_flavor(self, properties):
         log.info(_('Choosing the best flavor for given attributes.'))
         # Check whether user exported all required environment variables.
         flavors = FLAVORS
-        if self._check_for_env_variables():
+        if translator.common.utils.check_for_env_variables():
             resp = self._create_nova_flavor_dict()
             if resp:
                 flavors = resp
@@ -231,26 +250,32 @@ class ToscaCompute(HotResource):
             return None
 
     def _best_image(self, properties):
-        match_all = IMAGES.keys()
+        # Check whether user exported all required environment variables.
+        images = IMAGES
+        if translator.common.utils.check_for_env_variables():
+            resp = self._populate_image_dict()
+            if len(resp.keys()) > 0:
+                images = resp
+        match_all = images.keys()
         architecture = properties.get(self.ARCHITECTURE)
         if architecture is None:
             self._log_compute_msg(self.ARCHITECTURE, 'image')
-        match_arch = self._match_images(match_all, IMAGES,
+        match_arch = self._match_images(match_all, images,
                                         self.ARCHITECTURE, architecture)
         type = properties.get(self.TYPE)
         if type is None:
             self._log_compute_msg(self.TYPE, 'image')
-        match_type = self._match_images(match_arch, IMAGES, self.TYPE, type)
+        match_type = self._match_images(match_arch, images, self.TYPE, type)
         distribution = properties.get(self.DISTRIBUTION)
         if distribution is None:
             self._log_compute_msg(self.DISTRIBUTION, 'image')
-        match_distribution = self._match_images(match_type, IMAGES,
+        match_distribution = self._match_images(match_type, images,
                                                 self.DISTRIBUTION,
                                                 distribution)
         version = properties.get(self.VERSION)
         if version is None:
             self._log_compute_msg(self.VERSION, 'image')
-        match_version = self._match_images(match_distribution, IMAGES,
+        match_version = self._match_images(match_distribution, images,
                                            self.VERSION, version)
 
         if len(match_version):
