@@ -12,23 +12,26 @@
 # under the License.
 
 import logging
+from toscaparser.utils.gettextutils import _
 from translator.hot.syntax.hot_template import HotTemplate
 from translator.hot.translate_inputs import TranslateInputs
 from translator.hot.translate_node_templates import TranslateNodeTemplates
 from translator.hot.translate_outputs import TranslateOutputs
 
+log = logging.getLogger('heat-translator')
+
 
 class TOSCATranslator(object):
     '''Invokes translation methods.'''
 
-    log = logging.getLogger('heat-translator')
-
-    def __init__(self, tosca, parsed_params):
+    def __init__(self, tosca, parsed_params, deploy=None):
         super(TOSCATranslator, self).__init__()
         self.tosca = tosca
         self.hot_template = HotTemplate()
         self.parsed_params = parsed_params
+        self.deploy = deploy
         self.node_translator = None
+        log.info(_('Initialized parmaters for translation.'))
 
     def translate(self):
         self._resolve_input()
@@ -41,7 +44,8 @@ class TOSCATranslator(object):
         return self.hot_template.output_to_yaml()
 
     def _translate_inputs(self):
-        translator = TranslateInputs(self.tosca.inputs, self.parsed_params)
+        translator = TranslateInputs(self.tosca.inputs, self.parsed_params,
+                                     self.deploy)
         return translator.translate()
 
     def _translate_outputs(self):
@@ -58,7 +62,7 @@ class TOSCATranslator(object):
                         self.parsed_params[node_prop.value['get_input']]
                     except Exception:
                         msg = (_('Must specify all input values in \
-                                TOSCA template, missing %s') %
+                                TOSCA template, missing %s.') %
                                node_prop.value['get_input'])
-                        self.log.warning(msg)
+                        log.error(msg)
                         raise ValueError(msg)
